@@ -116,3 +116,6 @@ abind(cbind(a=1:3,b=4:6), cbind(a=7:9,b=10:12), hier.names=TRUE)
 abind(x=cbind(a=1:3,b=4:6), y=cbind(a=7:9,b=10:12), hier.names=TRUE)
 abind(x=cbind(1:3,4:6), y=cbind(7:9,10:12), hier.names=TRUE)
 abind(cbind(1:3,4:6), cbind(7:9,10:12), hier.names=TRUE)
+abind(x=cbind(a=1:3,b=4:6), hier.names='after')
+abind(x=cbind(a=1:3,b=4:6), hier.names='before')
+abind(x=cbind(a=1:3,b=4:6), hier.names='no')
